* let me hup/change/auto reload configs. i.e. i want a temporary 90s pause.
* allow suspend/status/etc in the CLI when waiting. - i.e. hit "s" to suspend. or possibly "p" to pause.
* make it a server that then will also run programs like pytest. then enable the cli to update/watch pytest.
* auto save to different "sessions" based on time period between last commit and save.
* advanced tqdm integration - i.e. status spinner when pushing/pulling.
* auto-freeze operation based on conflict. push notification that something is wrong (i.e. macos notification iun corner)
* repo groups - or tags? `ofnote`? ;)
* warranty. or lack there of.
* queuing up signed commits?
* watching a single file, then copying/moving to a filename that matches a predefined pattern.
* rules based on the content of the file that changed.
  - did these 3 files change? then tag it.
  - 
* `super supsrc supporter`


